# coding: utf-8

# flake8: noqa

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "20260212.2"

# import apis into sdk package
from pulpcore.client.pulp_service.api.api_create_domain_api import ApiCreateDomainApi
from pulpcore.client.pulp_service.api.api_debug_auth_header_api import ApiDebugAuthHeaderApi
from pulpcore.client.pulp_service.api.api_debug_database_triggers_api import ApiDebugDatabaseTriggersApi
from pulpcore.client.pulp_service.api.api_debug_release_task_locks_api import ApiDebugReleaseTaskLocksApi
from pulpcore.client.pulp_service.api.api_rds_connection_tests_api import ApiRdsConnectionTestsApi
from pulpcore.client.pulp_service.api.api_test_random_lock_tasks_api import ApiTestRandomLockTasksApi
from pulpcore.client.pulp_service.api.api_test_tasks_api import ApiTestTasksApi
from pulpcore.client.pulp_service.api.contentguards_feature_api import ContentguardsFeatureApi
from pulpcore.client.pulp_service.api.tasks_api import TasksApi
from pulpcore.client.pulp_service.api.vuln_report_service_api import VulnReportServiceApi

# import ApiClient
from pulpcore.client.pulp_service.api_response import ApiResponse
from pulpcore.client.pulp_service.api_client import ApiClient
from pulpcore.client.pulp_service.configuration import Configuration
from pulpcore.client.pulp_service.exceptions import OpenApiException
from pulpcore.client.pulp_service.exceptions import ApiTypeError
from pulpcore.client.pulp_service.exceptions import ApiValueError
from pulpcore.client.pulp_service.exceptions import ApiKeyError
from pulpcore.client.pulp_service.exceptions import ApiAttributeError
from pulpcore.client.pulp_service.exceptions import ApiException

# import models into sdk package
from pulpcore.client.pulp_service.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_service.models.domain import Domain
from pulpcore.client.pulp_service.models.domain_response import DomainResponse
from pulpcore.client.pulp_service.models.my_permissions_response import MyPermissionsResponse
from pulpcore.client.pulp_service.models.nested_role import NestedRole
from pulpcore.client.pulp_service.models.nested_role_response import NestedRoleResponse
from pulpcore.client.pulp_service.models.object_roles_response import ObjectRolesResponse
from pulpcore.client.pulp_service.models.paginated_task_response_list import PaginatedTaskResponseList
from pulpcore.client.pulp_service.models.paginatedservice_feature_content_guard_response_list import PaginatedserviceFeatureContentGuardResponseList
from pulpcore.client.pulp_service.models.paginatedservice_vulnerability_report_response_list import PaginatedserviceVulnerabilityReportResponseList
from pulpcore.client.pulp_service.models.patchedservice_feature_content_guard import PatchedserviceFeatureContentGuard
from pulpcore.client.pulp_service.models.progress_report_response import ProgressReportResponse
from pulpcore.client.pulp_service.models.service_feature_content_guard import ServiceFeatureContentGuard
from pulpcore.client.pulp_service.models.service_feature_content_guard_response import ServiceFeatureContentGuardResponse
from pulpcore.client.pulp_service.models.service_vulnerability_report_response import ServiceVulnerabilityReportResponse
from pulpcore.client.pulp_service.models.storage_class_enum import StorageClassEnum
from pulpcore.client.pulp_service.models.task_response import TaskResponse



# flake8: noqa

# import apis into api package
from pulpcore.client.pulp_service.api.api_create_domain_api import ApiCreateDomainApi
from pulpcore.client.pulp_service.api.api_debug_auth_header_api import ApiDebugAuthHeaderApi
from pulpcore.client.pulp_service.api.api_debug_database_triggers_api import ApiDebugDatabaseTriggersApi
from pulpcore.client.pulp_service.api.api_debug_release_task_locks_api import ApiDebugReleaseTaskLocksApi
from pulpcore.client.pulp_service.api.api_rds_connection_tests_api import ApiRdsConnectionTestsApi
from pulpcore.client.pulp_service.api.api_test_random_lock_tasks_api import ApiTestRandomLockTasksApi
from pulpcore.client.pulp_service.api.api_test_tasks_api import ApiTestTasksApi
from pulpcore.client.pulp_service.api.contentguards_feature_api import ContentguardsFeatureApi
from pulpcore.client.pulp_service.api.tasks_api import TasksApi
from pulpcore.client.pulp_service.api.vuln_report_service_api import VulnReportServiceApi




# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_service.models.task_response import TaskResponse

class TestTaskResponse(unittest.TestCase):
    """TaskResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TaskResponse:
        """Test TaskResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TaskResponse`
        """
        model = TaskResponse()
        if include_optional:
            return TaskResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                state = '',
                name = '',
                logging_cid = '',
                created_by = '',
                unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                error = pulpcore.client.pulp_service.models.error.error(),
                worker = '',
                parent_task = '',
                child_tasks = [
                    ''
                    ],
                task_group = '',
                progress_reports = [
                    pulpcore.client.pulp_service.models.progress_report_response.ProgressReportResponse(
                        message = '', 
                        code = '', 
                        state = '', 
                        total = 56, 
                        done = 56, 
                        suffix = '', )
                    ],
                created_resources = [
                    ''
                    ],
                reserved_resources_record = [
                    ''
                    ],
                result = None
            )
        else:
            return TaskResponse(
                name = '',
                logging_cid = '',
        )
        """

    def testTaskResponse(self):
        """Test TaskResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from pulpcore.client.pulp_service.models.progress_report_response import ProgressReportResponse
from typing import Optional, Set
from typing_extensions import Self

class TaskResponse(BaseModel):
    """
    Base serializer for use with [pulpcore.app.models.Model][]  This ensures that all Serializers provide values for the 'pulp_href` field.  The class provides a default for the ``ref_name`` attribute in the ModelSerializers's ``Meta`` class. This ensures that the OpenAPI definitions of plugins are namespaced properly.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    pulp_created: Optional[datetime] = Field(default=None, description="Timestamp of creation.")
    pulp_last_updated: Optional[datetime] = Field(default=None, description="Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.")
    state: Optional[StrictStr] = Field(default=None, description="The current state of the task. The possible values include: 'waiting', 'skipped', 'running', 'completed', 'failed', 'canceled' and 'canceling'.")
    name: StrictStr = Field(description="The name of task.")
    logging_cid: StrictStr = Field(description="The logging correlation id associated with this task")
    created_by: Optional[StrictStr] = Field(default=None, description="User who dispatched this task.")
    unblocked_at: Optional[datetime] = Field(default=None, description="Timestamp of when this task was identified ready for pickup.")
    started_at: Optional[datetime] = Field(default=None, description="Timestamp of when this task started execution.")
    finished_at: Optional[datetime] = Field(default=None, description="Timestamp of when this task stopped execution.")
    error: Optional[Dict[str, Any]] = Field(default=None, description="A JSON Object of a fatal error encountered during the execution of this task.")
    worker: Optional[StrictStr] = Field(default=None, description="DEPRECATED - Always null")
    parent_task: Optional[StrictStr] = Field(default=None, description="The parent task that spawned this task.")
    child_tasks: Optional[List[StrictStr]] = Field(default=None, description="Any tasks spawned by this task.")
    task_group: Optional[StrictStr] = Field(default=None, description="The task group that this task is a member of.")
    progress_reports: Optional[List[ProgressReportResponse]] = None
    created_resources: Optional[List[StrictStr]] = Field(default=None, description="Resources created by this task.")
    reserved_resources_record: Optional[List[StrictStr]] = Field(default=None, description="A list of resources required by that task.")
    result: Optional[Any] = Field(default=None, description="The result of this task.")
    __properties: ClassVar[List[str]] = ["pulp_href", "prn", "pulp_created", "pulp_last_updated", "state", "name", "logging_cid", "created_by", "unblocked_at", "started_at", "finished_at", "error", "worker", "parent_task", "child_tasks", "task_group", "progress_reports", "created_resources", "reserved_resources_record", "result"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TaskResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "prn",
            "pulp_created",
            "pulp_last_updated",
            "state",
            "created_by",
            "unblocked_at",
            "started_at",
            "finished_at",
            "error",
            "worker",
            "parent_task",
            "child_tasks",
            "task_group",
            "progress_reports",
            "created_resources",
            "reserved_resources_record",
            "result",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in progress_reports (list)
        _items = []
        if self.progress_reports:
            for _item_progress_reports in self.progress_reports:
                if _item_progress_reports:
                    _items.append(_item_progress_reports.to_dict())
            _dict['progress_reports'] = _items
        # set to None if created_by (nullable) is None
        # and model_fields_set contains the field
        if self.created_by is None and "created_by" in self.model_fields_set:
            _dict['created_by'] = None

        # set to None if worker (nullable) is None
        # and model_fields_set contains the field
        if self.worker is None and "worker" in self.model_fields_set:
            _dict['worker'] = None

        # set to None if result (nullable) is None
        # and model_fields_set contains the field
        if self.result is None and "result" in self.model_fields_set:
            _dict['result'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TaskResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pulp_href": obj.get("pulp_href"),
            "prn": obj.get("prn"),
            "pulp_created": obj.get("pulp_created"),
            "pulp_last_updated": obj.get("pulp_last_updated"),
            "state": obj.get("state"),
            "name": obj.get("name"),
            "logging_cid": obj.get("logging_cid"),
            "created_by": obj.get("created_by"),
            "unblocked_at": obj.get("unblocked_at"),
            "started_at": obj.get("started_at"),
            "finished_at": obj.get("finished_at"),
            "error": obj.get("error"),
            "worker": obj.get("worker"),
            "parent_task": obj.get("parent_task"),
            "child_tasks": obj.get("child_tasks"),
            "task_group": obj.get("task_group"),
            "progress_reports": [ProgressReportResponse.from_dict(_item) for _item in obj["progress_reports"]] if obj.get("progress_reports") is not None else None,
            "created_resources": obj.get("created_resources"),
            "reserved_resources_record": obj.get("reserved_resources_record"),
            "result": obj.get("result")
        })
        return _obj


